Official interfaces for ST components.

Dependents:   X_NUCLEO_IKS01A1 mDot_X_NUCLEO_IKS01A1 53L0A1 X_NUCLEO_IKS01A1 ... more

Fork of ST_INTERFACES by Davide Aliprandi

This library contains all abstract classes which together constitute the common API to which all existing and future ST components will adhere to.

Revision:
3:b1bb477e115e
Parent:
1:a7810e7acf8d
--- a/Sensors/HumiditySensor.h	Tue Nov 29 17:43:48 2016 +0000
+++ b/Sensors/HumiditySensor.h	Fri Mar 10 10:50:53 2017 +0100
@@ -36,25 +36,37 @@
  ******************************************************************************
  */
 
+
 /* Define to prevent from recursive inclusion --------------------------------*/
+
 #ifndef __HUMIDITY_SENSOR_CLASS_H
 #define __HUMIDITY_SENSOR_CLASS_H
 
+
 /* Includes ------------------------------------------------------------------*/
-#include <ComponentObject.h>
+
+#include <Component.h>
+
 
 /* Classes  ------------------------------------------------------------------*/
-/** An abstract class for Humidity sensors
+
+/**
+ * An abstract class for Humidity sensors
  */
-class HumiditySensor : public ComponentObject
-{
- public:
+class HumiditySensor : public Component {
+public:
+
 	/**
 	 * @brief       Get current humidity [%]
 	 * @param[out]  pfData Pointer to where to store humidity to
 	 * @return      0 in case of success, an error code otherwise
 	 */
-	virtual int GetHumidity(float *pfData) = 0;
+	virtual int get_humidity(float *pf_data) = 0;
+
+    /**
+     * @brief Destructor.
+     */
+	virtual ~HumiditySensor() {};
 };
 
 #endif /* __HUMIDITY_SENSOR_CLASS_H */
@@ -36,25 +36,37 @@
 	/**
 	 * @brief       Get current humidity [%]
-	 * @param[out]  pfData Pointer to where to store humidity to
+	 * @param[out]  pf_data Pointer to where to store humidity to
 	 * @return      0 in case of success, an error code otherwise
 	 */